---
date: 2024-02-02
authors: [matt]
description: >
  Reuse parts layout across designs
categories:
  - Release
links:
---

# ✨ Layout Reuse ✨

Huge shout out to @nickkrstevski for this awesome new feature!

You can now reuse parts placement across designs. This is a huge time saver for designs - particularly those with a lot of common modules.

<picture>
    <source type="image/avif" srcset="/assets/images/placement-reuse.avif" />
    <img src="/assets/images/placement-reuse.gif" />
</picture>

## OMG, How?

Usage of the `ato` CLI will automatically install the hook for the atopile plugin to KiCAD.
All you need to do is hit the sync 🔄 button to group the components into the modules that have layouts associated, then hit pull ⬇️ to use that layout. If you want to save a layout to a module, you can do so with the push ⬆️ button.


Happy designing! 🎉

Matt
